@@ -21,13 +21,16 @@ import pygtk
 import gtk, glib
 import os, tempfile
 import subprocess
-from config_builder import ConfigBuilder
 import host_settings
 import gettext
-from dots_project import DotsProject
-from document_builder import document_new
 import gconf
 import gtkunixprint
+import pango
+from dots_project import DotsProject
+from document_builder import document_new
+from document_builder import get_supported_mime_types
+from document_builder import get_supported_extensiones_patterns
+from config_builder import ConfigBuilder
 from table_editor import TableEditor
 from translator import Translator
 
@@ -55,41 +58,17 @@ class AppWindow(object):
 	self.conf_xml.set_translation_domain(host_settings.DOMAIN)
         self.conf_xml.add_from_file (
             os.path.join(host_settings.gtkbuilder_dir, 'config.xml'))
- 
+
+        view = self.main_xml.get_object('textview1')
+	view.modify_font(pango.FontDescription('Mono'))
 	self.loadConfig()
 
     def loadConfig(self):
-	self.config_builder['xml']['semanticFiles'] = self.client.get_string ("/apps/dots/semanticFiles")
-	if self.client.get_bool ("/apps/dots/internetAccess"):
-		self.config_builder['xml']['internetAccess'] = 'yes'
-	else:
-		self.config_builder['xml']['internetAccess'] = 'no'
-	self.config_builder['translation']['literaryTextTable'] = self.client.get_string ("/apps/dots/literaryTextTable")
-	self.config_builder['outputFormat']['cellsPerLine'] = self.client.get_int ("/apps/dots/cellsPerLine")
-	if self.client.get_bool ("/apps/dots/braillePages"):
-		self.config_builder['outputFormat']['braillePages'] = 'yes'
-	else:
-		self.config_builder['outputFormat']['braillePages'] = 'no'
-	self.config_builder['outputFormat']['formatFor'] = self.client.get_string ("/apps/dots/formatFor")
-	self.config_builder['outputFormat']['LinesPerPage'] = self.client.get_int ("/apps/dots/LinesPerPage")
-	self.config_builder['outputFormat']['braillePageNumberAt'] =  self.client.get_string ("/apps/dots/braillePageNumberAt")
+	self.config_builder.load_from_gconf(self.client)
 	self._populateTablesMenu()
 
     def saveConfig(self):
-	self.client.set_string ("/apps/dots/semanticFiles", self.config_builder['xml']['semanticFiles'])
-	if self.config_builder['xml']['internetAccess'] == 'yes':
-		self.client.set_bool ("/apps/dots/internetAccess", True)
-	else:
-		self.client.set_bool ("/apps/dots/internetAccess", False)
-	self.client.set_string ("/apps/dots/literaryTextTable", self.config_builder['translation']['literaryTextTable'])
-	self.client.set_int ("/apps/dots/cellsPerLine", self.config_builder['outputFormat']['cellsPerLine'])
-	if self.config_builder['outputFormat']['braillePages'] == 'yes':
-		self.client.set_bool ("/apps/dots/braillePages", True)
-	else:
-		self.client.set_bool ("/apps/dots/braillePages", False)
-	self.client.set_string ("/apps/dots/formatFor", self.config_builder['outputFormat']['formatFor'])
-	self.client.set_int ("/apps/dots/LinesPerPage", self.config_builder['outputFormat']['LinesPerPage'])
-	self.client.set_string ("/apps/dots/braillePageNumberAt", self.config_builder['outputFormat']['braillePageNumberAt'])
+	self.config_builder.save_to_gconf(self.client)
 
     def _OnTranslationFormatActivate(self, item):
 	dialog = self.conf_xml.get_object('format_dialog')
@@ -122,7 +101,7 @@ class AppWindow(object):
 			self.config_builder['outputFormat']['braillePageNumberAt'] = "bottom"
 		else:
 			self.config_builder['outputFormat']['braillePages'] = "no"
-		
+
 		if self.document is not None:
 			self.translate (self.document, self.config_builder)
 
@@ -180,7 +159,7 @@ class AppWindow(object):
 		#	dialog.run()
 		#	dialog.hide()
 		#	return
-	
+
 		eitem = self._addTable (self.submenu, file, True)
 		eitem.activate()
 		eitem.show()
@@ -197,12 +176,12 @@ class AppWindow(object):
 		dialog.hide()
 		self.config_builder['translation']['literaryTextTable'] = old_table
 		return
-	
+
 
 	if self.document is not None:
 		self.translate (self.document, self.config_builder)
-	
-	
+
+
 
     def _populateTablesMenu(self):
         def _sepatatorFunc(model, itr):
@@ -246,18 +225,10 @@ class AppWindow(object):
 
 	filter = gtk.FileFilter()
 	filter.set_name(_("Documents"))
-	filter.add_mime_type("application/pdf")
-	filter.add_mime_type("application/vnd.oasis.opendocument.text")
-	filter.add_mime_type("application/xhtml+xml")
-	filter.add_mime_type("application/xml")
-	filter.add_mime_type("text/plain")
-	filter.add_mime_type("text/html")
-	filter.add_pattern("*.pdf")
-	filter.add_pattern("*.odt")
-	filter.add_pattern("*.txt")
-	filter.add_pattern("*.html")
-	filter.add_pattern("*.xhtml")
-	filter.add_pattern("*.xml")
+	for m in get_supported_mime_types():
+		filter.add_mime_type(m)
+	for p in get_supported_extensiones_patterns():
+		filter.add_pattern(p)
 	chooser.add_filter(filter)
 	chooser.set_filter(filter)
  	response = chooser.run()
@@ -265,16 +236,46 @@ class AppWindow(object):
 	chooser.destroy()
 	if response == gtk.RESPONSE_OK:
 		self.document = document_new (filename)
+		# TODO: Check for None here, although we should not get
+		#       non-supported mime-types from the filechooser
 		self.addDocument (self.document)
 		self.translate (self.document, self.config_builder)
 
+    def _onNew(self, action):
+	view = self.main_xml.get_object('textview1')
+	view.set_sensitive(True)
+	view.set_editable(True)
+	self.document = document_new (None)
+	self.addDocument (self.document)
+	action = self.main_xml.get_object('action_translate')
+	action.set_sensitive(True)
+	self.statusbar = self.main_xml.get_object('statusbar1')
+	context_id = self.statusbar.get_context_id("text file")
+	self.statusbar.push(context_id, _("Text editable"))
+	view.grab_focus()
+
+    def _onTranslate(self, action):
+	# We are translating the text buffer, so set it to the document
+	action = self.main_xml.get_object('action_translate')
+	action.set_sensitive(False)
+	context_id = self.statusbar.get_context_id("text file")
+	self.statusbar.pop(context_id)
+	view = self.main_xml.get_object('textview1')
+	view.set_editable(False)
+	buffer = view.get_buffer()
+	self.document.set_text (buffer.get_text(
+                                self.project.buffer.get_start_iter(),
+                                self.project.buffer.get_end_iter()))
+	self.translate(self.document, self.config_builder)
+	
+	
     def _OnRevisionLine(self, item):
 	reviewentry = self.main_xml.get_object('reviewentry')
 	if item.get_active():
         	reviewentry.show()
 	else:
         	reviewentry.hide()
-		
+
 
     def _OnBrailleViewToggle(self, ascii_item):
         if ascii_item.get_active():
@@ -284,7 +285,7 @@ class AppWindow(object):
 
     def _onLineChanged(self, view, project, line):
 	self.main_xml.get_object('reviewentry').set_text(line)
-	
+
 
     def _onSave(self, action):
         if self.project.out_file is None:
@@ -295,7 +296,7 @@ class AppWindow(object):
                     self.project.buffer.get_start_iter(),
                     self.project.buffer.get_end_iter()))
             fsave.close()
-            self.project.buffer.set_modified(False)            
+            self.project.buffer.set_modified(False)
 
     def _onSaveAs(self, action):
         dialog = gtk.FileChooserDialog(parent=self.window,
@@ -313,17 +314,16 @@ class AppWindow(object):
                     self.project.buffer.get_end_iter()))
             fsave.close()
             self.project.out_file = dialog.get_filename()
-            self.project.set_name(os.path.basename(self.project.out_file))
             self.project.buffer.set_modified(False)
-            
+
         dialog.destroy()
 
     def _printJobSent(self, job, data, errormsg):
 	if errormsg is not None:
 		print "Error printing: " + errormsg
-	
+
 	os.unlink(data)
-		
+
 
     def _onPrint(self, action):
 	dialog = gtkunixprint.PrintUnixDialog()
@@ -359,15 +359,18 @@ class AppWindow(object):
 
 
     def addDocument(self, document):
-	container = self.main_xml.get_object('main_alignment')
 	if self.project is not None:
-		container.remove (self.project)
-		self.project.destroy()
-
-        self.project = DotsProject(document, _("Unsaved Document"))
-	container.add(self.project)
-	self.window.set_title(os.path.basename(document.input_file) + " - dots")
-        self.project.show_all()
+		del self.project
+        self.project = DotsProject(document, _("Unsaved Document"), self.main_xml.get_object("textview1"))
+	ascii_radio = self.main_xml.get_object("ascii_radio")
+	if ascii_radio.get_active():
+            self.project.view_ascii()
+        else:
+            self.project.view_braille()
+	if document.input_file is not None:
+		self.window.set_title("Dots - " + os.path.basename(document.input_file))
+	else:
+		self.window.set_title("Dots")
 	self.project.connect("line-changed", self._onLineChanged)
 
     def translate(self, document, config):
@@ -387,11 +390,37 @@ class AppWindow(object):
 	return res
 
 
+    # FIXME: this should be doable in glade
+    def _add_control_key(self, widget, accel_group, key):
+	widget.add_accelerator("activate", accel_group, ord(key),
+                               gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
 
+    def _add_shift_control_key(self, widget, accel_group, key):
+	widget.add_accelerator("activate", accel_group, ord(key),
+                               gtk.gdk.SHIFT_MASK | gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
+
+
+
+    def _menu_add_accels(self):
+	accel_group = gtk.AccelGroup()
+	self.window.add_accel_group(accel_group)
+	self._add_control_key(self.main_xml.get_object('menu_new'), accel_group, 'n')
+	self._add_control_key(self.main_xml.get_object('menu_open'), accel_group, 'o')
+	self._add_control_key(self.main_xml.get_object('menu_save'), accel_group, 's')
+	self._add_shift_control_key(self.main_xml.get_object('menu_save_as'), accel_group, 's')
+	self._add_control_key(self.main_xml.get_object('menu_print'), accel_group, 'p')
+	self._add_control_key(self.main_xml.get_object('menu_quit'), accel_group, 'q')
+	self._add_control_key(self.main_xml.get_object('menu_translate'), accel_group, 't')
+	self._add_control_key(self.main_xml.get_object('ascii_radio'), accel_group, 'a')
+	self._add_control_key(self.main_xml.get_object('braille_radio'), accel_group, 'b')
+	self._add_control_key(self.main_xml.get_object('line_check'), accel_group, 'l')
+	self._add_control_key(self.main_xml.get_object('menu_format'), accel_group, 'f')
+	self.main_xml.get_object('menu_help').add_accelerator("activate", accel_group, gtk.keysyms.F1, 0, gtk.ACCEL_VISIBLE)
 
     def run(self):
         self.window.show_all()
         self.main_xml.get_object('reviewentry').hide()
+	self._menu_add_accels()
         gtk.main()
 
     def _onHelp(self, action):
