@@ -205,7 +205,7 @@ class EditDialog(gtk.Dialog):
 			#action
 		}
 		self.entries = []
-	
+
 		operands_list = []
 		if operands is not None:
 			operands_list = operands.split(" ")
@@ -237,7 +237,7 @@ class EditDialog(gtk.Dialog):
 		if len(comments) > 0:
 			comments.reverse()
 			entry.set_text (" ".join (comments).lstrip(" "))
-	
+
 
 	def combo_changed(self, combo):
 		remove = False
@@ -254,7 +254,7 @@ class EditDialog(gtk.Dialog):
 		self.add_entries_for_opcode (vbox, opcode, [])
 		self.add_comments (vbox, [])
 		vbox.show_all()
-		
+
 	def add_opcode_combo(self, vbox, opcode):
 		label = gtk.Label ("opcode:")
 		combo = gtk.ComboBox()
@@ -308,12 +308,12 @@ class EditDialog(gtk.Dialog):
 		opcode = c.get_model().get_value(iter, 0)
 		for e in self.entries:
 			if isinstance(e, gtk.Entry):
-				operands += e.get_text() + " " 
+				operands += e.get_text() + " "
 			elif isinstance(e, gtk.ComboBox):
 				iter = e.get_active_iter()
 				operands += e.get_model().get_value(iter, 0) + " "
 		return opcode, operands
-				
+
 
 	def validate_text(self, entry, string, len, position):
 		opcode = entry.get_data("opcode")
@@ -420,7 +420,7 @@ class TableEditor(gtk.Dialog):
 			selection.select_iter(iter)
 			view.scroll_to_cell(model.get_path(iter))
 		dialog.destroy()
-	
+
 
 	def remove_clicked(self,button, view):
 		selection = view.get_selection();
@@ -431,8 +431,8 @@ class TableEditor(gtk.Dialog):
 
 		selection = view.get_selection();
 		model, iter = selection.get_selected()
-		opcode = model.get_value (iter, 0)	
-		operands = model.get_value (iter, 1)	
+		opcode = model.get_value (iter, 0)
+		operands = model.get_value (iter, 1)
 		dialog = EditDialog (opcode, operands)
 		dialog.set_transient_for(self)
 
@@ -485,22 +485,23 @@ class TableEditor(gtk.Dialog):
 			error = res.split(":", )
 			dialog = gtk.MessageDialog(self, gtk.DIALOG_DESTROY_WITH_PARENT,
                                                    gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE,
-                                                   _("Error in table at line ") + error[1] + ": " + error[2])
+                                                   _("Error in table at line %(line)s: %(error)s") % {
+                                                   'line': error[1], 'error': error[2]})
 			dialog.run()
 			dialog.destroy()
 			path = str(int(error[1]) - 1)
 			self.treeview.get_selection().select_path(path)
 			self.treeview.scroll_to_cell(path)
 			self.run()
-			
-		
-		
-		
 
 
 
-	
-		
+
+
+
+
+
+
 
 
 if __name__ == "__main__":
@@ -514,4 +515,4 @@ if __name__ == "__main__":
 
 	gtk.main()
 
-	
+
